# Radiosat - Simulation of satellite pass and radio communication

[![PyPI - Version](https://img.shields.io/pypi/v/radiosat)](https://pypi.org/project/radiosat/)

## Description

Radiosat is a Python package to simulate satellite passes with radio communication. It enables to develop algorithms to track satellites based on their radio emission, for example to optimize the signal quality or correct the orbit predictions.

## Installation

This package can be very easily installed using pip :

 ```pip install radiosat```

## Contributing

Contributions are welcome! Please open an issue or submit a pull request on GitHub.

## License

This project is licensed under the GNU General Public License v3 (GPLv3). See the LICENSE file for details.